@@ -3,6 +3,7 @@
 namespace PhpParser\Node\Stmt;
 
 use PhpParser\Node;
+
 class Declare_ extends Node\Stmt
 {
     /** @var DeclareDeclare[] List of declares */
@@ -14,11 +15,11 @@ class Declare_ extends Node\Stmt
      * Constructs a declare node.
      *
      * @param DeclareDeclare[] $declares   List of declares
-     * @param Node[]           $stmts      Statements
+     * @param Node[]|null      $stmts      Statements
      * @param array            $attributes Additional attributes
      */
-    public function __construct(array $declares, array $stmts, array $attributes = array()) {
-        parent::__construct(null, $attributes);
+    public function __construct(array $declares, array $stmts = null, array $attributes = array()) {
+        parent::__construct($attributes);
         $this->declares = $declares;
         $this->stmts = $stmts;
     }
